translate.storage.placeables.terminology

Package translate :: Package storage :: Package placeables :: Module terminology |
[hide private]
[frames] | no frames]

# Module terminology

source code

Contains the placeable that represents a terminology term.

Classes | [hide private]
| TerminologyPlaceable Terminology distinguished from the rest of a string by being a placeable.

Variables | [hide private]
| parsers = ``[`<bound method type.parse of <class 'translate.stora`...``

Imports: base, StringElem

Variables Details | [hide private]

  ### parsers Value:
      [<bound method type.parse of <class 'translate.storage.placeables.term
      inology.TerminologyPlaceable'>>]